/**
 * File navigation.js.
 *
 * Handles toggling the navigation menu for small screens and enables TAB key
 * navigation support for dropdown menus.
 */
( function() {
    var greatwp_secondary_container, greatwp_secondary_button, greatwp_secondary_menu, greatwp_secondary_links, greatwp_secondary_i, greatwp_secondary_len;

    greatwp_secondary_container = document.getElementById( 'greatwp-secondary-navigation' );
    if ( ! greatwp_secondary_container ) {
        return;
    }

    greatwp_secondary_button = greatwp_secondary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof greatwp_secondary_button ) {
        return;
    }

    greatwp_secondary_menu = greatwp_secondary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof greatwp_secondary_menu ) {
        greatwp_secondary_button.style.display = 'none';
        return;
    }

    greatwp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === greatwp_secondary_menu.className.indexOf( 'nav-menu' ) ) {
        greatwp_secondary_menu.className += ' nav-menu';
    }

    greatwp_secondary_button.onclick = function() {
        if ( -1 !== greatwp_secondary_container.className.indexOf( 'greatwp-toggled' ) ) {
            greatwp_secondary_container.className = greatwp_secondary_container.className.replace( ' greatwp-toggled', '' );
            greatwp_secondary_button.setAttribute( 'aria-expanded', 'false' );
            greatwp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            greatwp_secondary_container.className += ' greatwp-toggled';
            greatwp_secondary_button.setAttribute( 'aria-expanded', 'true' );
            greatwp_secondary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    greatwp_secondary_links    = greatwp_secondary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( greatwp_secondary_i = 0, greatwp_secondary_len = greatwp_secondary_links.length; greatwp_secondary_i < greatwp_secondary_len; greatwp_secondary_i++ ) {
        greatwp_secondary_links[greatwp_secondary_i].addEventListener( 'focus', greatwp_secondary_toggleFocus, true );
        greatwp_secondary_links[greatwp_secondary_i].addEventListener( 'blur', greatwp_secondary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function greatwp_secondary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'greatwp-focus' ) ) {
                    self.className = self.className.replace( ' greatwp-focus', '' );
                } else {
                    self.className += ' greatwp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( greatwp_secondary_container ) {
        var touchStartFn, greatwp_secondary_i,
            parentLink = greatwp_secondary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, greatwp_secondary_i;

                if ( ! menuItem.classList.contains( 'greatwp-focus' ) ) {
                    e.preventDefault();
                    for ( greatwp_secondary_i = 0; greatwp_secondary_i < menuItem.parentNode.children.length; ++greatwp_secondary_i ) {
                        if ( menuItem === menuItem.parentNode.children[greatwp_secondary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[greatwp_secondary_i].classList.remove( 'greatwp-focus' );
                    }
                    menuItem.classList.add( 'greatwp-focus' );
                } else {
                    menuItem.classList.remove( 'greatwp-focus' );
                }
            };

            for ( greatwp_secondary_i = 0; greatwp_secondary_i < parentLink.length; ++greatwp_secondary_i ) {
                parentLink[greatwp_secondary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( greatwp_secondary_container ) );
} )();


( function() {
    var greatwp_primary_container, greatwp_primary_button, greatwp_primary_menu, greatwp_primary_links, greatwp_primary_i, greatwp_primary_len;

    greatwp_primary_container = document.getElementById( 'greatwp-primary-navigation' );
    if ( ! greatwp_primary_container ) {
        return;
    }

    greatwp_primary_button = greatwp_primary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof greatwp_primary_button ) {
        return;
    }

    greatwp_primary_menu = greatwp_primary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof greatwp_primary_menu ) {
        greatwp_primary_button.style.display = 'none';
        return;
    }

    greatwp_primary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === greatwp_primary_menu.className.indexOf( 'nav-menu' ) ) {
        greatwp_primary_menu.className += ' nav-menu';
    }

    greatwp_primary_button.onclick = function() {
        if ( -1 !== greatwp_primary_container.className.indexOf( 'greatwp-toggled' ) ) {
            greatwp_primary_container.className = greatwp_primary_container.className.replace( ' greatwp-toggled', '' );
            greatwp_primary_button.setAttribute( 'aria-expanded', 'false' );
            greatwp_primary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            greatwp_primary_container.className += ' greatwp-toggled';
            greatwp_primary_button.setAttribute( 'aria-expanded', 'true' );
            greatwp_primary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    greatwp_primary_links    = greatwp_primary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( greatwp_primary_i = 0, greatwp_primary_len = greatwp_primary_links.length; greatwp_primary_i < greatwp_primary_len; greatwp_primary_i++ ) {
        greatwp_primary_links[greatwp_primary_i].addEventListener( 'focus', greatwp_primary_toggleFocus, true );
        greatwp_primary_links[greatwp_primary_i].addEventListener( 'blur', greatwp_primary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function greatwp_primary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'greatwp-focus' ) ) {
                    self.className = self.className.replace( ' greatwp-focus', '' );
                } else {
                    self.className += ' greatwp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( greatwp_primary_container ) {
        var touchStartFn, greatwp_primary_i,
            parentLink = greatwp_primary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, greatwp_primary_i;

                if ( ! menuItem.classList.contains( 'greatwp-focus' ) ) {
                    e.preventDefault();
                    for ( greatwp_primary_i = 0; greatwp_primary_i < menuItem.parentNode.children.length; ++greatwp_primary_i ) {
                        if ( menuItem === menuItem.parentNode.children[greatwp_primary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[greatwp_primary_i].classList.remove( 'greatwp-focus' );
                    }
                    menuItem.classList.add( 'greatwp-focus' );
                } else {
                    menuItem.classList.remove( 'greatwp-focus' );
                }
            };

            for ( greatwp_primary_i = 0; greatwp_primary_i < parentLink.length; ++greatwp_primary_i ) {
                parentLink[greatwp_primary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( greatwp_primary_container ) );
} )();